@@ -22,6 +22,7 @@ class Client(object):
     '''
 
     def __init__(self,
+                 api_token=None,
                  username=None,
                  password=None,
                  program_token=None,
@@ -31,12 +32,13 @@ class Client(object):
         Create an instance of the API interface.
         This is the main interface the user will call to interact with the API.
         '''
+        self._api_token = api_token
         self._username = username
         self._password = password
         self._program_token = program_token
         self._active_experiments = set()
         self._server = server
-        self._api_client = ApiClient(self._username, self._password, self._server, encryption_data)
+        self._api_client = ApiClient(self._api_token, self._username, self._password, self._server, encryption_data)
 
     def create_workspace(self, name):
         '''
