@@ -82,4 +82,10 @@ class Monitor(ABC):
         '''
         Returns the NTCore endpoint for sending experiment data.
         '''
-        return '/'.join(s.strip('/') for s in paths)
\ No newline at end of file
+        return '/'.join(s.strip('/') for s in paths)
+
+    def get_workspace_id(self):
+        '''
+        Returns the workspace id for this monitor.
+        '''
+        return self._workspace_id
\ No newline at end of file
